%
% This function saves the given plot in three formats, emf
% (enhanced windows metafile), eps (encapsulated postscript), and fig (matlab
% figure). The emf format is used for plots incorporated into powerpoint/word documents. 
% The eps format is platform independent and is used for displaying plots 
% in documents written in latex. The reason for this dual saving is that the 
% postscript display in word/powerpoint is horrible, so we save to both
% formats. Finally, the plot is saved in matlab's fig format. The reason for
% this is that the default 3D camera position often doesn't give an optimal 
% visualization of the data. To fix this, the user opens the fig file positions 
% the camera and manually saves the emf and eps files without rerunning scripts.
% This function is very similar to saveFigure, it actually uses saveFigure
% to do the saving. The reason for its existance is that it allows the user
% to save a plot displayed as part of a GUI without including all of the
% GUI in the figure.
% 
% @param outputFilePrefix Prefix for the file name. Given the prefix 'xyz'
%                         this function will create the files 'xyz.emf',
%                         'xyz.eps', and 'xyz.fig'.
%
% @param axesHandle The axes we want to save.
%
% @param varargin{1} Optional parameter, the file name suffix. Valid values are
%                    'eps', 'emf', 'fig'. If one of these suffixes is used
%                    then the function will save the figure in the
%                    corresponding format. If this is an empty string then save in
%                    all three formats.
%
% @param varargin{2} Optional parameter, the plot's legend. In matlab the
%                    legend is a child of the figure and not of the axes in
%                    which it is drawn. Thus, we cannot get at the legend
%                    handle using the axesHandle. It is up to the user to
%                    get the correct legend.
%                    
% @author Ziv Yaniv (zivy@isis.georgetown.edu)
%
function savePlot(outputFilePrefix, axesHandle, varargin)

  figureHandle = figure;
  set(figureHandle, 'Colormap', colormap(axesHandle));
  
             %copy the axes to the new figure
  copiedAxes = copyobj(axesHandle, figureHandle);
              %align the axes object on the new figure using its original
              %size
  axesUnits = get(axesHandle, 'Units');
  axesPosition = get(axesHandle, 'Position');            
  set(copiedAxes, 'Units', axesUnits);
  set(copiedAxes, 'Position', [1 1 axesPosition(3) axesPosition(4)]);
  
  
               %modify the figure size according to the axes size        
  set(figureHandle, 'Units', axesUnits);
  set(figureHandle, 'Position', [1 1 axesPosition(3) axesPosition(4)]);
  
         %if we got more than three arguments then the fourth one is a legend
  if nargin > 3
    copiedLegend = copyobj(varargin{2}, figureHandle);
              %align the legend object on the new figure using its original
              %size    
    legendUnits = get(varargin{2}, 'Units');
    legendPosition = get(varargin{2}, 'Position');
    set(copiedLegend, 'Units', legendUnits);
    set(copiedLegend, 'Position', [legendPosition(1),...
                                   legendPosition(2),... 
                                   legendPosition(3),...
                                   legendPosition(4)] );
  end
  if nargin>2 && ~isempty(varargin{1})
    saveFigure(figureHandle, outputFilePrefix, varargin{1});
  else
    saveFigure(figureHandle, outputFilePrefix);
  end
  close(figureHandle);
  
